@@ -2,5 +2,17 @@
 
 """A python wrapper around `bacting <https://github.com/egonw/bacting>`_."""
 
-from .api import cdk, inchi, opsin, pubchem  # noqa:F401
+from .api import (  # noqa:F401
+    biojava,
+    bridgedb,
+    cdk,
+    excel,
+    inchi,
+    opsin,
+    oscar,
+    pubchem,
+    qudt,
+    rdf,
+    xml,
+)
 from .io import from_iupac_name, from_smiles, get_inchi, get_inchi_key, get_svg  # noqa:F401
