@@ -5,25 +5,26 @@
 from scyjava import config, jimport, start_jvm
 
 __all__ = [
-    "cdk",
-    "opsin",
-    "inchi",
-    "pubchem",
-    "xml",
-    "rdf",
-    "oscar",
-    "bridgedb",
-    "excel",
     "biojava",
+    "bridgedb",
+    "cdk",
+    "excel",
+    "inchi",
+    "opsin",
+    "oscar",
+    "pubchem",
+    "qudt",
+    "rdf",
+    "xml",
 ]
 
 WORKSPACE = "."
-VERSION = "0.0.26"
+VERSION = "0.0.33"
 
 # The ones marked with "no" can't be loaded because they are POM-only
 # artifacts. See the excellent explanation given by @ctrueden why at:
 # https://github.com/scijava/scyjava/issues/30#issuecomment-892061823
-config.add_endpoints(
+endpoints = (
     # f"io.github.egonw.bacting:managers-semweb:{VERSION}", # no
     f"io.github.egonw.bacting:managers-inchi:{VERSION}",
     f"io.github.egonw.bacting:managers-pubchem:{VERSION}",
@@ -40,6 +41,7 @@ config.add_endpoints(
     f"io.github.egonw.bacting:managers-bridgedb:{VERSION}",
     f"io.github.egonw.bacting:bacting-core:{VERSION}",
 )
+config.endpoints.extend(endpoints)
 
 # Connecting to the JVM is usually done implicitly, but since spreading
 # the endpoints and instantiation across many classes causes a problem,
@@ -95,3 +97,7 @@ excel = excel_cls(WORKSPACE)
 biojava_cls = jimport("net.bioclipse.managers.BiojavaManager")
 biojava = biojava_cls(WORKSPACE)
 """The BioJava manager from Bacting."""
+
+qudt_cls = jimport("net.bioclipse.managers.QUDTManager")
+qudt = qudt_cls(WORKSPACE)
+"""The quantity conversion manager from Bacting."""
